// Forlix PlaySound
// http://forlix.org/, df@forlix.org
//
// Copyright (c) 2009-2013 Dominik Friedrichs

#include "_main.inc"

static bool:late_load = false;


public APLRes:AskPluginLoad2(Handle:myself,
                             bool:late,
                             String:error[],
                             err_max)
{
  late_load = late;
  return(APLRes_Success);
}


public OnPluginStart()
{
  RegConsoleCmd(PLAY_COMMAND, Command_Play, "Plays back a sound from Forlix PlaySound.");

  RegConsoleCmd("say", Command_Say);
  RegConsoleCmd("say_team", Command_Say);

  HookEvent("round_start", Event_RoundStart);

  SetupConVars();

  Cookie_PluginStart();
  Playback_PluginStart();

  h_trie_snds = CreateTrie();
  h_array_snds = CreateArray(MAX_SOUND_LEN);

  return;
}


public OnPluginEnd()
{
  WriteEveryPlayersCookie();

  CloseHandle(h_trie_snds);
  CloseHandle(h_array_snds);

  return;
}


public OnMapStart()
{
  ReadSoundList(CONFIG_PATH);
  LoadTranslations(TRANSLATION_FILE);

  if(late_load)
  {
    FullRegenerate();
    ReadEveryPlayersCookie();
  }

  late_load = false;
  return;
}


public OnClientConnected(client)
{
  p_sounds[client] = float(successive_sounds);
  p_flags[client] = 0;

  return;
}


public OnClientCookiesCached(client)
{
  if(IsClientConnected(client))
    ReadPlayersCookie(client);

  return;
}


public OnClientDisconnect(client)
{
  WritePlayersCookie(client);
  return;
}


public Event_RoundStart(Handle:event,
                        const String:Event_type[],
                        bool:dontBroadcast)
{
  FullRegenerate();
  return;
}


public Action:Command_Play(client, args)
{
  // +2 for quotes, +1 to see if string goes on
  decl String:text[MAX_SOUND_LEN+2+1];
  GetCmdArgString(text, sizeof(text));

  StripQuotes(text);
  StringToLower(text);

  PlaySound(client, text, true);

  return(Plugin_Handled);
}


public Action:Command_Say(client, args)
{
  decl String:text[MAX_MSG_LEN+2];
  GetCmdArgString(text, sizeof(text));

  StripQuotes(text);
  StringToLower(text);

  if(!strcmp(text, help_cmd))
  // help command was typed
  {
    if(client)
    {
      HelpPanel(client, args);
      return(Plugin_Handled);
    }
    else
      return(Plugin_Continue);
  }

  if(PlaySound(client, text))
  // sound found and played back
    return(Plugin_Handled);

  if(client
  && StrContains(text, "sound") >= 0)
  // player is probably looking for the soundlist
    ReplyWithDeadTimeBlock(client, "%t", "PLAYSOUND_HELP", help_cmd);

  return(Plugin_Continue);
}
