// Forlix PlaySound
// http://forlix.org/, df@forlix.org
//
// Copyright (c) 2009-2013 Dominik Friedrichs

// convar defaults
#define LOG_PLAYBACKS             "1"

#define SOUND_OVERLAPPING         "0"
#define SUCCESSIVE_SOUNDS         "3"
#define REGENERATE_PER_MINUTE     "3"

#define SOUNDLIST_URL             "none"
#define CHAT_TRIGGER              "!"

static Handle:h_log_playbacks = INVALID_HANDLE;

static Handle:h_sound_overlapping = INVALID_HANDLE;
static Handle:h_successive_sounds = INVALID_HANDLE;
static Handle:h_regenerate_per_minute = INVALID_HANDLE;

static Handle:h_soundlist_url = INVALID_HANDLE;
static Handle:h_chat_trigger = INVALID_HANDLE;


SetupConVars()
{
  new Handle:version_cvar = CreateConVar(PLUGIN_VERSION_CVAR,
  PLUGIN_VERSION,
  "Forlix PlaySound plugin version",
  FCVAR_PLUGIN|FCVAR_SPONLY|FCVAR_NOTIFY|FCVAR_PRINTABLEONLY);

  SetConVarString(version_cvar, PLUGIN_VERSION, false, false);

  h_log_playbacks = CreateConVar("forlix_playsound_log_playbacks",
  LOG_PLAYBACKS,
  "Enables (1) or disables (0) sound playback logging",
  0, true, 0.0, true, 1.0);

  h_sound_overlapping = CreateConVar("forlix_playsound_sound_overlapping",
  SOUND_OVERLAPPING,
  "Enables (1) or disables (0) sound overlapping (When 0, any sound stops the previous one)",
  0, true, 0.0, true, 1.0);

  h_successive_sounds = CreateConVar("forlix_playsound_successive_sounds",
  SUCCESSIVE_SOUNDS,
  "Amount of sounds a player can play back in quick succession (0 to disable sounds)",
  0, true, 0.0, true, 240.0);

  h_regenerate_per_minute = CreateConVar("forlix_playsound_regenerate_per_minute",
  REGENERATE_PER_MINUTE,
  "Regeneration rate of sounds per minute (after 1 minute player can play another N sounds)",
  0, true, 0.0, true, 240.0);

  h_soundlist_url = CreateConVar("forlix_playsound_soundlist_url",
  SOUNDLIST_URL,
  "URL to the HTML soundlist (set to \"none\" to disable)",
  FCVAR_PRINTABLEONLY);

  h_chat_trigger = CreateConVar("forlix_playsound_chat_trigger",
  CHAT_TRIGGER,
  "Set this to one of the ChatTrigger strings configured in SourceMod's core.cfg",
  FCVAR_PRINTABLEONLY);

  HookConVarChange(h_log_playbacks, MyConVarChanged);

  HookConVarChange(h_sound_overlapping, MyConVarChanged);
  HookConVarChange(h_successive_sounds, MyConVarChanged);
  HookConVarChange(h_regenerate_per_minute, MyConVarChanged);

  HookConVarChange(h_soundlist_url, MyConVarChanged);
  HookConVarChange(h_chat_trigger, MyConVarChanged);

  // manually trigger convar readout
  MyConVarChanged(INVALID_HANDLE, "0", "0");

  return;
}


public MyConVarChanged(Handle:convar,
                       const String:oldValue[],
                       const String:newValue[])
{
  log_playbacks = GetConVarInt(h_log_playbacks);

  sound_overlapping = GetConVarInt(h_sound_overlapping);
  successive_sounds = GetConVarInt(h_successive_sounds);
  regenerate_per_minute = GetConVarFloat(h_regenerate_per_minute);

  GetConVarString(h_soundlist_url, soundlist_url, sizeof(soundlist_url));
  GetConVarString(h_chat_trigger, help_cmd, sizeof(help_cmd));
  StrCat(help_cmd, sizeof(help_cmd), PLUGIN_COMMAND);

  FullRegenerate();
  return;
}
