// Forlix PlaySound
// http://forlix.org/, df@forlix.org
//
// Copyright (c) 2009-2013 Dominik Friedrichs


bool:ReadSoundList(const String:config_path[])
{
  decl String:path[PLATFORM_MAX_PATH];
  BuildPath(Path_SM, path, sizeof(path), config_path);

  new Handle:h_snds = CreateKeyValues("playsounds");

  if(!FileToKeyValues(h_snds, path))
    SetFailState("Configuration file \"%s\" not found", path);

  // clear trie and repopulate with current soundlist
  ClearTrie(h_trie_snds);
  ClearArray(h_array_snds);

  sounds_listed = 0;

  if(KvGotoFirstSubKey(h_snds, false))
  do
  {
    decl String:snd_name[MAX_SOUND_LEN];
    decl String:snd_path[PLATFORM_MAX_PATH];

    KvGetSectionName(h_snds, snd_name, sizeof(snd_name));
    KvGetString(h_snds, NULL_STRING, snd_path, sizeof(snd_path));

    StringToLower(snd_name);

    decl String:full_path[PLATFORM_MAX_PATH] = "sound/";
    StrCat(full_path, sizeof(full_path), snd_path);

    if(!FileExists(full_path, true))
    {
      LogError("\"%s\" does not exist", full_path);
      continue;
    }

    if(!SetTrieString(h_trie_snds, snd_name, snd_path, false))
    {
      LogError("\"%s\": duplicate alias", snd_name);
      continue;
    }

    AddFileToDownloadsTable(full_path);

    PrecacheSound(snd_path, true);
    PrefetchSound(snd_path);

    PushArrayString(h_array_snds, snd_name);
    sounds_listed++;
  }
  while(KvGotoNextKey(h_snds, false));

  CloseHandle(h_snds);
  SortADTArray(h_array_snds, Sort_Ascending, Sort_String);

  return;
}


PrintSoundlistTo(client, bool:console)
{
  if(console)
  {
    PrintToConsole(client, " \n%t", "SOUNDLIST_TITLE");

    for(new i = 0; i < sounds_listed; i++)
    {
      decl String:snd_name[MAX_SOUND_LEN];
      GetArrayString(h_array_snds, i, snd_name, sizeof(snd_name));

      PrintToConsole(client, "%u. %s", i+1, snd_name);
    }

    PrintToConsole(client, " ");
    PrintToChat(client, "%t", "SOUNDLIST_IN_CONSOLE");
  }
  else
  {
    PrintToChat(client, " \n%t", "SOUNDLIST_TITLE");

    for(new i = 0; i < sounds_listed; i++)
    {
      decl String:snd_name[MAX_SOUND_LEN];
      GetArrayString(h_array_snds, i, snd_name, sizeof(snd_name));

      PrintToChat(client, "%u. %s", i+1, snd_name);
    }

    PrintToChat(client, " ");
  }

  return;
}
